﻿using Newtonsoft.Json;
using System;
using System.Collections.Generic;
using System.IO;

namespace FNZCM.Core
{
    public interface IConfigFile
    {
        string AdminPassword { get; }
        IReadOnlyCollection<string> AliasPrefix { get; }
        IReadOnlyCollection<string> AccessControlAllowOrigin { get; }
        IReadOnlyDictionary<string, string> Libraries { get; }

        string[] MediaFilePattern { get; }
        string[] BkFilePattern { get; }
        string ListenPrefix { get; }
        string Title { get; }

        IReadOnlyDictionary<string, ModuleEntry> Modules { get; }
    }

    public class ConfigFile : IConfigFile
    {
        static ConfigFile() => Reload();

        public static void Reload() => Instance = JsonConvert.DeserializeObject<ConfigFile>(File.ReadAllText(Path.Combine(AppDomain.CurrentDomain.BaseDirectory, "config.json")));

        public string AdminPassword { get; set; }
        public IReadOnlyCollection<string> AliasPrefix { get; set; }
        public IReadOnlyCollection<string> AccessControlAllowOrigin { get; set; }

        public string ListenPrefix { get; set; }

        public string Title { get; set; }

        public IReadOnlyDictionary<string, string> Libraries { get; set; }
        public string[] MediaFilePattern { get; set; }
        public string[] BkFilePattern { get; set; }

        public static IConfigFile Instance { get; private set; }

        public IReadOnlyDictionary<string, ModuleEntry> Modules { get; set; }
    }

    public class ModuleEntry
    {
        public bool IsDefault { get; set; }
        public string DisplayText { get; set; }
        public string Path { get; set; }

        public bool EnableFallbackRoute { get; set; }
        public string DefaultDocument { get; set; }
        public string HtmlBaseReplace { get; set; }
    }
}
